# Python Tools for Applications of Interval Design

## Requirements

Python 3.11+

## Installation

```console
$ pip install interval-tools
```

Or if you want to use [ObjectID](https://www.mongodb.com/docs/manual/reference/bson-types/#objectid) as a unique identifier in Domain-Driven Design, run

```console
$ pip install "interval-tools[objectid]"
```
